Message

Enum Message 

#[non_exhaustive]
pub enum Message {
Show 30 variants RequestVote(RequestVote), RequestVoteResponse(RequestVoteResponse), PreVote(PreVote), PreVoteResponse(PreVoteResponse), TimeoutNow(TimeoutNow), AppendEntries(AppendEntries), AppendEntriesResponse(AppendEntriesResponse), BlockRequest(BlockRequest), BlockResponse(BlockResponse), SnapshotRequest(SnapshotRequest), SnapshotResponse(SnapshotResponse), Ping { term: u64, }, Pong { term: u64, }, TxPrepare(TxPrepareMsg), TxPrepareResponse(TxPrepareResponseMsg), TxCommit(TxCommitMsg), TxAbort(TxAbortMsg), TxAck(TxAckMsg), QueryRequest(QueryRequest), QueryResponse(QueryResponse), Gossip(GossipMessage), SignedGossip(SignedGossipMessage), MergeInit(MergeInit), MergeAck(MergeAck), ViewExchange(MergeViewExchange), DataMergeRequest(DataMergeRequest), DataMergeResponse(DataMergeResponse), TxReconcileRequest(TxReconcileRequest), TxReconcileResponse(TxReconcileResponse), MergeFinalize(MergeFinalize),
}
Message types for consensus protocol.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


RequestVote(RequestVote)

Request vote during leader election.



RequestVoteResponse(RequestVoteResponse)

Response to vote request.



PreVote(PreVote)

Pre-vote request (prevents disruptive elections).



PreVoteResponse(PreVoteResponse)

Response to pre-vote request.



TimeoutNow(TimeoutNow)

Immediate election trigger for leadership transfer.



AppendEntries(AppendEntries)

Append entries (log replication).



AppendEntriesResponse(AppendEntriesResponse)

Response to append entries.



BlockRequest(BlockRequest)

Request blocks from a peer.



BlockResponse(BlockResponse)

Response with requested blocks.



SnapshotRequest(SnapshotRequest)

Request state snapshot.



SnapshotResponse(SnapshotResponse)

Response with state snapshot chunk.



Ping

Ping to check liveness.

Fields

term: u64


Pong

Pong response.

Fields

term: u64


TxPrepare(TxPrepareMsg)

Prepare request for distributed transaction.



TxPrepareResponse(TxPrepareResponseMsg)

Vote response for prepare request.



TxCommit(TxCommitMsg)

Commit request for distributed transaction.



TxAbort(TxAbortMsg)

Abort request for distributed transaction.



TxAck(TxAckMsg)

Response to commit/abort.



QueryRequest(QueryRequest)

Request to execute a query on a remote shard.



QueryResponse(QueryResponse)

Response with query results.



Gossip(GossipMessage)

Gossip message for membership protocol.



SignedGossip(SignedGossipMessage)

Signed gossip message with Ed25519 authentication and replay protection.



MergeInit(MergeInit)

Initialize merge session after partition heal.



MergeAck(MergeAck)

Acknowledge merge initialization.



ViewExchange(MergeViewExchange)

Exchange membership view summaries.



DataMergeRequest(DataMergeRequest)

Request data merge information.



DataMergeResponse(DataMergeResponse)

Response with data merge information.



TxReconcileRequest(TxReconcileRequest)

Request transaction reconciliation.



TxReconcileResponse(TxReconcileResponse)

Response with transaction reconciliation result.



MergeFinalize(MergeFinalize)

Finalize merge session.

Implementations

Source

impl Message

pub const fn routing_embedding(&self) -> Option<&SparseVector>

Extract the routing embedding from a message for geometric routing decisions.

Returns the most semantically relevant embedding for the message type:

  • RequestVote/PreVote: candidate’s state embedding
  • AppendEntries: block embedding (if present)
  • TxPrepare: transaction delta embedding
pub const fn has_routing_embedding(&self) -> bool

pub const fn type_name(&self) -> &'static str